@@ -11,4 +11,12 @@ sub subroutine {
     return "subroutine return: $arg1, $arg2";
 }
 
+sub empty_prototype() {
+    return 'empty_prototype';
+}
+
+sub scalar_prototype($) {
+    return 'scalar_prototype ' . $ARG[ 0 ];
+}
+
 1;
